﻿using System;
using System.Collections.Generic;
using System.ComponentModel;
using System.Data;
using System.Drawing;
using System.Linq;
using System.Text;
using System.Windows.Forms;
using ThinkGeo.MapSuite.Core;
using ThinkGeo.MapSuite.DesktopEdition;

namespace WindowsFormsApplication1
{
    public partial class Form1 : Form
    {
        private int previousValue;

        public Form1()
        {
            InitializeComponent();

            winformsMap1.MouseWheel += new MouseEventHandler(winformsMap1_MouseWheel);
        }

        private void winformsMap1_MouseWheel(object sender, MouseEventArgs e)
        {
            if (e.Delta > 0)
            {
                if (trbZoomLevel.Value < trbZoomLevel.Maximum)
                {
                    trbZoomLevel.Value += 1;
                }
            }
            else
            {
                if (trbZoomLevel.Value > trbZoomLevel.Minimum)
                {
                    trbZoomLevel.Value -= 1;
                }
            }
            previousValue = trbZoomLevel.Value;
        }

        private void trbZoomLevel_MouseUp(object sender, MouseEventArgs e)
        {
            if (previousValue != trbZoomLevel.Value)
            {
                SetZoom(previousValue, trbZoomLevel.Value);
                previousValue = trbZoomLevel.Value;
            }
        }

        private void Form1_Load(object sender, EventArgs e)
        {
            previousValue = trbZoomLevel.Value;

            ShapeFileFeatureLayer layer1 = new ShapeFileFeatureLayer(@"..\..\data\Austinstreets.shp");
            layer1.ZoomLevelSet.ZoomLevel01.ApplyUntilZoomLevel = ApplyUntilZoomLevel.Level20;
            layer1.ZoomLevelSet.ZoomLevel01.DefaultLineStyle = LineStyles.Canal1;

            LayerOverlay overlay1 = new LayerOverlay();
            overlay1.Layers.Add("layer1", layer1);

            layer1.Open();
            winformsMap1.CurrentExtent = layer1.GetBoundingBox();
            layer1.Close();
            winformsMap1.MapUnit = GeographyUnit.DecimalDegree;
            winformsMap1.MaximumScale = GetMaximumScale(1, 1);
            winformsMap1.MinimumScale = GetMinimumScale(1, 10);

            winformsMap1.Overlays.Add("overlay1", overlay1);
            winformsMap1.Refresh();
        }

        private void SetZoom(int previousValue, int currentValue)
        {
            if (currentValue > previousValue)
            {
                for (int i = 0; i < currentValue - previousValue; i++)
                {
                    double nextScale = ZoomLevelSet.GetLowerZoomLevelScale(winformsMap1.CurrentScale, winformsMap1.ZoomLevelSet);
                    winformsMap1.ZoomToScale(nextScale);
                }
            }
            else
            {
                for (int i = 0; i < previousValue - currentValue; i++)
                {
                    double nextScale = ZoomLevelSet.GetHigherZoomLevelScale(winformsMap1.CurrentScale, winformsMap1.ZoomLevelSet);
                    winformsMap1.ZoomToScale(nextScale);
                }
            }
            winformsMap1.Refresh();

        }

        private double GetMinimumScale(int currentLevel, int maximumLevel)
        {
            double nextScale = winformsMap1.CurrentScale;
            for (int i = 0; i < maximumLevel - currentLevel - 1; i++)
            {
                nextScale = ZoomLevelSet.GetLowerZoomLevelScale(nextScale, winformsMap1.ZoomLevelSet);
            }
            return nextScale;
        }

        private double GetMaximumScale(int currentLevel, int minimumLevel)
        {
            double nextScale = winformsMap1.CurrentScale;
            for (int i = 0; i < currentLevel - minimumLevel - 1; i++)
            {
                nextScale = ZoomLevelSet.GetHigherZoomLevelScale(nextScale, winformsMap1.ZoomLevelSet);
            }
            return nextScale;
        }
    }
}
